==> sipay-1.0.0-py3-none-any.whl: sipay/catalogs/currency.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
CURRENCIES = {
    'AED': ('AED', '784', 2, 'Dírham de los Emiratos Árabes Unidos'),
    'AFN': ('AFN', '971', 2, 'Afgani'),
    'ALL': ('ALL', '8', 2, 'Lek'),
    'AMD': ('AMD', '51', 2, 'Dram armenio'),
    'ANG': ('ANG', '532', 2, 'Florín antillano neerlandés'),
    'AOA': ('AOA', '973', 2, 'Kwanza'),
    'ARS': ('ARS', '32', 2, 'Peso argentino'),
    'AUD': ('AUD', '36', 2, 'Dólar australiano'),
    'AWG': ('AWG', '533', 2, 'Florín arubeño'),
    'AZN': ('AZN', '944', 2, 'Manat azerbaiyano'),
    'BAM': ('BAM', '977', 2, 'Marco convertible'),
    'BBD': ('BBD', '52', 2, 'Dólar de Barbados'),
    'BDT': ('BDT', '50', 2, 'Taka'),
    'BGN': ('BGN', '975', 2, 'Lev búlgaro'),
    'BHD': ('BHD', '48', 3, 'Dinar bareiní'),
    'BIF': ('BIF', '108', 0, 'Franco de Burundi'),
    'BMD': ('BMD', '60', 2, 'Dólar bermudeño'),
    'BND': ('BND', '96', 2, 'Dólar de Brunéi'),
    'BOB': ('BOB', '68', 2, 'Boliviano'),
    'BOV': ('BOV', '984', 2, 'MVDOL'),
    'BRL': ('BRL', '986', 2, 'Real brasileño'),
    'BSD': ('BSD', '44', 2, 'Dólar bahameño'),
    'BTN': ('BTN', '64', 2, 'Ngultrum'),
    'BWP': ('BWP', '72', 2, 'Pula'),
    'BYR': ('BYR', '974', 0, 'Rublo bielorruso'),
    'BZD': ('BZD', '84', 2, 'Dólar beliceño'),
    'CAD': ('CAD', '124', 2, 'Dólar canadiense'),
    'CDF': ('CDF', '976', 2, 'Franco congoleño'),
    'CHE': ('CHE', '947', 2, 'Euro WIR'),
    'CHF': ('CHF', '756', 2, 'Franco suizo'),
    'CHW': ('CHW', '948', 2, 'Franco WIR'),
    'CLF': ('CLF', '990', 4, 'Unidad de fomento'),
    'CLP': ('CLP', '152', 0, 'Peso chileno'),
    'CNY': ('CNY', '156', 2, 'Yuan chino'),
    'COP': ('COP', '170', 2, 'Peso colombiano'),
    'COU': ('COU', '970', 2, 'Unidad de valor real'),
    'CRC': ('CRC', '188', 2, 'Colón costarricense'),
    'CUC': ('CUC', '931', 2, 'Peso convertible'),
    'CUP': ('CUP', '192', 2, 'Peso cubano'),
    'CVE': ('CVE', '132', 2, 'Escudo caboverdiano'),
    'CZK': ('CZK', '203', 2, 'Corona checa'),
    'DJF': ('DJF', '262', 0, 'Franco yibutiano'),
    'DKK': ('DKK', '208', 2, 'Corona danesa'),
    'DOP': ('DOP', '214', 2, 'Peso dominicano'),
    'DZD': ('DZD', '12', 2, 'Dinar argelino'),
    'EGP': ('EGP', '818', 2, 'Libra egipcia'),
    'ERN': ('ERN', '232', 2, 'Nakfa'),
    'ETB': ('ETB', '230', 2, 'Birr etíope'),
    'EUR': ('EUR', '978', 2, 'Euro'),
    'FJD': ('FJD', '242', 2, 'Dólar fiyiano'),
    'FKP': ('FKP', '238', 2, 'Libra malvinense'),
    'GBP': ('GBP', '826', 2, 'Libra esterlina'),
    'GEL': ('GEL', '981', 2, 'Lari'),
    'GHS': ('GHS', '936', 2, 'Cedi ghanés'),
    'GIP': ('GIP', '292', 2, 'Libra de Gibraltar'),
    'GMD': ('GMD', '270', 2, 'Dalasi'),
    'GNF': ('GNF', '324', 0, 'Franco guineano'),
    'GTQ': ('GTQ', '320', 2, 'Quetzal'),
    'GYD': ('GYD', '328', 2, 'Dólar guyanés'),
    'HKD': ('HKD', '344', 2, 'Dólar de Hong Kong'),
    'HNL': ('HNL', '340', 2, 'Lempira'),
    'HRK': ('HRK', '191', 2, 'Kuna'),
    'HTG': ('HTG', '332', 2, 'Gourde'),
    'HUF': ('HUF', '348', 2, 'Forinto'),
    'IDR': ('IDR', '360', 2, 'Rupia indonesia'),
    'ILS': ('ILS', '376', 2, 'Nuevo shéquel israelí'),
    'INR': ('INR', '356', 2, 'Rupia india'),
    'IQD': ('IQD', '368', 3, 'Dinar iraquí'),
    'IRR': ('IRR', '364', 2, 'Rial iraní'),
    'ISK': ('ISK', '352', 0, 'Corona islandesa'),
    'JMD': ('JMD', '388', 2, 'Dólar jamaiquino'),
    'JOD': ('JOD', '400', 3, 'Dinar jordano'),
    'JPY': ('JPY', '392', 0, 'Yen'),
    'KES': ('KES', '404', 2, 'Chelín keniano'),
    'KGS': ('KGS', '417', 2, 'Som'),
    'KHR': ('KHR', '116', 2, 'Riel'),
    'KMF': ('KMF', '174', 0, 'Franco comorense'),
    'KPW': ('KPW', '408', 2, 'Won norcoreano'),
    'KRW': ('KRW', '410', 0, 'Won'),
    'KWD': ('KWD', '414', 3, 'Dinar kuwaití'),
    'KYD': ('KYD', '136', 2, 'Dólar de las Islas Caimán'),
    'KZT': ('KZT', '398', 2, 'Tenge'),
    'LAK': ('LAK', '418', 2, 'Kip'),
    'LBP': ('LBP', '422', 2, 'Libra libanesa'),
    'LKR': ('LKR', '144', 2, 'Rupia de Sri Lanka'),
    'LRD': ('LRD', '430', 2, 'Dólar liberiano'),
    'LSL': ('LSL', '426', 2, 'Loti'),
    'LYD': ('LYD', '434', 3, 'Dinar libio'),
    'MAD': ('MAD', '504', 2, 'Dírham marroquí'),
    'MDL': ('MDL', '498', 2, 'Leu moldavo'),
    'MGA': ('MGA', '969', 2, 'Ariary malgache'),
    'MKD': ('MKD', '807', 2, 'Denar'),
    'MMK': ('MMK', '104', 2, 'Kyat'),
    'MNT': ('MNT', '496', 2, 'Tugrik'),
    'MOP': ('MOP', '446', 2, 'Pataca'),
    'MRO': ('MRO', '478', 2, 'Uquiya'),
    'MUR': ('MUR', '480', 2, 'Rupia de Mauricio'),
    'MVR': ('MVR', '462', 2, 'Rufiyaa'),
    'MWK': ('MWK', '454', 2, 'Kwacha'),
    'MXN': ('MXN', '484', 2, 'Peso mexicano'),
    'MXV': ('MXV', '979', 2, 'Unidad de Inversión (UDI) mexicana'),
    'MYR': ('MYR', '458', 2, 'Ringgit malayo'),
    'MZN': ('MZN', '943', 2, 'Metical mozambiqueño'),
    'NAD': ('NAD', '516', 2, 'Dólar namibio'),
    'NGN': ('NGN', '566', 2, 'Naira'),
    'NIO': ('NIO', '558', 2, 'Córdoba'),
    'NOK': ('NOK', '578', 2, 'Corona noruega'),
    'NPR': ('NPR', '524', 2, 'Rupia nepalí'),
    'NZD': ('NZD', '554', 2, 'Dólar neozelandés'),
    'OMR': ('OMR', '512', 3, 'Rial omaní'),
    'PAB': ('PAB', '590', 2, 'Balboa'),
    'PEN': ('PEN', '604', 2, 'Sol'),
    'PGK': ('PGK', '598', 2, 'Kina'),
    'PHP': ('PHP', '608', 2, 'Peso filipino'),
    'PKR': ('PKR', '586', 2, 'Rupia pakistaní'),
    'PLN': ('PLN', '985', 2, 'Złoty'),
    'PYG': ('PYG', '600', 0, 'Guaraní'),
    'QAR': ('QAR', '634', 2, 'Riyal qatarí'),
    'RON': ('RON', '946', 2, 'Leu rumano'),
    'RSD': ('RSD', '941', 2, 'Dinar serbio'),
    'RUB': ('RUB', '643', 2, 'Rublo ruso'),
    'RWF': ('RWF', '646', 0, 'Franco ruandés'),
    'SAR': ('SAR', '682', 2, 'Riyal saudí'),
    'SBD': ('SBD', '90', 2, 'Dólar de las Islas Salomón'),
    'SCR': ('SCR', '690', 2, 'Rupia seychelense'),
    'SDG': ('SDG', '938', 2, 'Dinar sudanés'),
    'SEK': ('SEK', '752', 2, 'Corona sueca'),
    'SGD': ('SGD', '702', 2, 'Dólar de Singapur'),
    'SHP': ('SHP', '654', 2, 'Libra de Santa Elena'),
    'SLL': ('SLL', '694', 2, 'Leone'),
    'SOS': ('SOS', '706', 2, 'Chelín somalí'),
    'SRD': ('SRD', '968', 2, 'Dólar surinamés'),
    'SSP': ('SSP', '728', 2, 'Libra sursudanesa'),
    'STD': ('STD', '678', 2, 'Dobra'),
    'SVC': ('SVC', '222', 2, 'Colon Salvadoreño'),
    'SYP': ('SYP', '760', 2, 'Libra siria'),
    'SZL': ('SZL', '748', 2, 'Lilangeni'),
    'THB': ('THB', '764', 2, 'Baht'),
    'TJS': ('TJS', '972', 2, 'Somoni tayiko'),
    'TMT': ('TMT', '934', 2, 'Manat turcomano'),
    'TND': ('TND', '788', 3, 'Dinar tunecino'),
    'TOP': ('TOP', '776', 2, 'Paʻanga'),
    'TRY': ('TRY', '949', 2, 'Lira turca'),
    'TTD': ('TTD', '780', 2, 'Dólar de Trinidad y Tobago'),
    'TWD': ('TWD', '901', 2, 'Nuevo dólar taiwanés'),
    'TZS': ('TZS', '834', 2, 'Chelín tanzano'),
    'UAH': ('UAH', '980', 2, 'Grivna'),
    'UGX': ('UGX', '800', 0, 'Chelín ugandés'),
    'USD': ('USD', '840', 2, 'Dólar estadounidense'),
    'USN': ('USN', '997', 2, 'Dólar estadounidense (Siguiente día)'),
    'UYI': ('UYI', '940', 0, 'Peso en Unidades Indexadas (Uruguay)'),
    'UYU': ('UYU', '858', 2, 'Peso uruguayo'),
    'UZS': ('UZS', '860', 2, 'Som uzbeko'),
    'VEF': ('VEF', '937', 2, 'Bolívar'),
    'VND': ('VND', '704', 0, 'Dong vietnamita'),
    'VUV': ('VUV', '548', 0, 'Vatu'),
    'WST': ('WST', '882', 2, 'Tala'),
    'XAF': ('XAF', '950', 0, 'Franco CFA de África Central'),
    'XAG': ('XAG', '961', -1, 'Plata (una onza troy)'),
    'XAU': ('XAU', '959', -1, 'Oro (una onza troy)'),
    'XBA': ('XBA', '955', -1, 'Unidad compuesta europea (EURCO) (Unidad del mercados de bonos)'),
    'XBB': ('XBB', '956', -1, 'Unidad Monetaria europea (E.M.U.-6) (Unidad del mercado de bonos)'),
    'XBC': ('XBC', '957', -1, 'Unidad europea de cuenta 9 (E.U.A.-9) (Unidad del mercado de bonos)'),
    'XBD': ('XBD', '958', -1, 'Unidad europea de cuenta 17 (E.U.A.-17) (Unidad del mercado de bonos)'),
    'XCD': ('XCD', '951', 2, 'Dólar del Caribe Oriental'),
    'XDR': ('XDR', '960', -1, 'Derechos especiales de giro'),
    'XOF': ('XOF', '952', 0, 'Franco CFA de África Occidental'),
    'XPD': ('XPD', '964', -1, 'Paladio (una onza troy)'),
    'XPF': ('XPF', '953', 0, 'Franco CFP'),
    'XPT': ('XPT', '962', -1, 'Platino (una onza troy)'),
    'XSU': ('XSU', '994', -1, 'SUCRE'),
    'XTS': ('XTS', '963', -1, 'Reservado para pruebas'),
    'XUA': ('XUA', '965', -1, 'Unidad de cuenta BAD'),
    'XXX': ('XXX', '999', -1, 'Sin divisa'),
    'YER': ('YER', '886', 2, 'Rial yemení'),
    'ZAR': ('ZAR', '710', 2, 'Rand'),
    'ZMW': ('ZMW', '967', 2, 'Kwacha zambiano'),
    'ZWL': ('ZWL', '932', 2, 'Dólar zimbabuense')
}

==> sipay-1.1.0-py3-none-any.whl: sipay/catalogs/currency.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
CURRENCIES = {
    'AED': ('AED', '784', 2, 'Dírham de los Emiratos Árabes Unidos'),
    'AFN': ('AFN', '971', 2, 'Afgani'),
    'ALL': ('ALL', '8', 2, 'Lek'),
    'AMD': ('AMD', '51', 2, 'Dram armenio'),
    'ANG': ('ANG', '532', 2, 'Florín antillano neerlandés'),
    'AOA': ('AOA', '973', 2, 'Kwanza'),
    'ARS': ('ARS', '32', 2, 'Peso argentino'),
    'AUD': ('AUD', '36', 2, 'Dólar australiano'),
    'AWG': ('AWG', '533', 2, 'Florín arubeño'),
    'AZN': ('AZN', '944', 2, 'Manat azerbaiyano'),
    'BAM': ('BAM', '977', 2, 'Marco convertible'),
    'BBD': ('BBD', '52', 2, 'Dólar de Barbados'),
    'BDT': ('BDT', '50', 2, 'Taka'),
    'BGN': ('BGN', '975', 2, 'Lev búlgaro'),
    'BHD': ('BHD', '48', 3, 'Dinar bareiní'),
    'BIF': ('BIF', '108', 0, 'Franco de Burundi'),
    'BMD': ('BMD', '60', 2, 'Dólar bermudeño'),
    'BND': ('BND', '96', 2, 'Dólar de Brunéi'),
    'BOB': ('BOB', '68', 2, 'Boliviano'),
    'BOV': ('BOV', '984', 2, 'MVDOL'),
    'BRL': ('BRL', '986', 2, 'Real brasileño'),
    'BSD': ('BSD', '44', 2, 'Dólar bahameño'),
    'BTN': ('BTN', '64', 2, 'Ngultrum'),
    'BWP': ('BWP', '72', 2, 'Pula'),
    'BYR': ('BYR', '974', 0, 'Rublo bielorruso'),
    'BZD': ('BZD', '84', 2, 'Dólar beliceño'),
    'CAD': ('CAD', '124', 2, 'Dólar canadiense'),
    'CDF': ('CDF', '976', 2, 'Franco congoleño'),
    'CHE': ('CHE', '947', 2, 'Euro WIR'),
    'CHF': ('CHF', '756', 2, 'Franco suizo'),
    'CHW': ('CHW', '948', 2, 'Franco WIR'),
    'CLF': ('CLF', '990', 4, 'Unidad de fomento'),
    'CLP': ('CLP', '152', 0, 'Peso chileno'),
    'CNY': ('CNY', '156', 2, 'Yuan chino'),
    'COP': ('COP', '170', 2, 'Peso colombiano'),
    'COU': ('COU', '970', 2, 'Unidad de valor real'),
    'CRC': ('CRC', '188', 2, 'Colón costarricense'),
    'CUC': ('CUC', '931', 2, 'Peso convertible'),
    'CUP': ('CUP', '192', 2, 'Peso cubano'),
    'CVE': ('CVE', '132', 2, 'Escudo caboverdiano'),
    'CZK': ('CZK', '203', 2, 'Corona checa'),
    'DJF': ('DJF', '262', 0, 'Franco yibutiano'),
    'DKK': ('DKK', '208', 2, 'Corona danesa'),
    'DOP': ('DOP', '214', 2, 'Peso dominicano'),
    'DZD': ('DZD', '12', 2, 'Dinar argelino'),
    'EGP': ('EGP', '818', 2, 'Libra egipcia'),
    'ERN': ('ERN', '232', 2, 'Nakfa'),
    'ETB': ('ETB', '230', 2, 'Birr etíope'),
    'EUR': ('EUR', '978', 2, 'Euro'),
    'FJD': ('FJD', '242', 2, 'Dólar fiyiano'),
    'FKP': ('FKP', '238', 2, 'Libra malvinense'),
    'GBP': ('GBP', '826', 2, 'Libra esterlina'),
    'GEL': ('GEL', '981', 2, 'Lari'),
    'GHS': ('GHS', '936', 2, 'Cedi ghanés'),
    'GIP': ('GIP', '292', 2, 'Libra de Gibraltar'),
    'GMD': ('GMD', '270', 2, 'Dalasi'),
    'GNF': ('GNF', '324', 0, 'Franco guineano'),
    'GTQ': ('GTQ', '320', 2, 'Quetzal'),
    'GYD': ('GYD', '328', 2, 'Dólar guyanés'),
    'HKD': ('HKD', '344', 2, 'Dólar de Hong Kong'),
    'HNL': ('HNL', '340', 2, 'Lempira'),
    'HRK': ('HRK', '191', 2, 'Kuna'),
    'HTG': ('HTG', '332', 2, 'Gourde'),
    'HUF': ('HUF', '348', 2, 'Forinto'),
    'IDR': ('IDR', '360', 2, 'Rupia indonesia'),
    'ILS': ('ILS', '376', 2, 'Nuevo shéquel israelí'),
    'INR': ('INR', '356', 2, 'Rupia india'),
    'IQD': ('IQD', '368', 3, 'Dinar iraquí'),
    'IRR': ('IRR', '364', 2, 'Rial iraní'),
    'ISK': ('ISK', '352', 0, 'Corona islandesa'),
    'JMD': ('JMD', '388', 2, 'Dólar jamaiquino'),
    'JOD': ('JOD', '400', 3, 'Dinar jordano'),
    'JPY': ('JPY', '392', 0, 'Yen'),
    'KES': ('KES', '404', 2, 'Chelín keniano'),
    'KGS': ('KGS', '417', 2, 'Som'),
    'KHR': ('KHR', '116', 2, 'Riel'),
    'KMF': ('KMF', '174', 0, 'Franco comorense'),
    'KPW': ('KPW', '408', 2, 'Won norcoreano'),
    'KRW': ('KRW', '410', 0, 'Won'),
    'KWD': ('KWD', '414', 3, 'Dinar kuwaití'),
    'KYD': ('KYD', '136', 2, 'Dólar de las Islas Caimán'),
    'KZT': ('KZT', '398', 2, 'Tenge'),
    'LAK': ('LAK', '418', 2, 'Kip'),
    'LBP': ('LBP', '422', 2, 'Libra libanesa'),
    'LKR': ('LKR', '144', 2, 'Rupia de Sri Lanka'),
    'LRD': ('LRD', '430', 2, 'Dólar liberiano'),
    'LSL': ('LSL', '426', 2, 'Loti'),
    'LYD': ('LYD', '434', 3, 'Dinar libio'),
    'MAD': ('MAD', '504', 2, 'Dírham marroquí'),
    'MDL': ('MDL', '498', 2, 'Leu moldavo'),
    'MGA': ('MGA', '969', 2, 'Ariary malgache'),
    'MKD': ('MKD', '807', 2, 'Denar'),
    'MMK': ('MMK', '104', 2, 'Kyat'),
    'MNT': ('MNT', '496', 2, 'Tugrik'),
    'MOP': ('MOP', '446', 2, 'Pataca'),
    'MRO': ('MRO', '478', 2, 'Uquiya'),
    'MUR': ('MUR', '480', 2, 'Rupia de Mauricio'),
    'MVR': ('MVR', '462', 2, 'Rufiyaa'),
    'MWK': ('MWK', '454', 2, 'Kwacha'),
    'MXN': ('MXN', '484', 2, 'Peso mexicano'),
    'MXV': ('MXV', '979', 2, 'Unidad de Inversión (UDI) mexicana'),
    'MYR': ('MYR', '458', 2, 'Ringgit malayo'),
    'MZN': ('MZN', '943', 2, 'Metical mozambiqueño'),
    'NAD': ('NAD', '516', 2, 'Dólar namibio'),
    'NGN': ('NGN', '566', 2, 'Naira'),
    'NIO': ('NIO', '558', 2, 'Córdoba'),
    'NOK': ('NOK', '578', 2, 'Corona noruega'),
    'NPR': ('NPR', '524', 2, 'Rupia nepalí'),
    'NZD': ('NZD', '554', 2, 'Dólar neozelandés'),
    'OMR': ('OMR', '512', 3, 'Rial omaní'),
    'PAB': ('PAB', '590', 2, 'Balboa'),
    'PEN': ('PEN', '604', 2, 'Sol'),
    'PGK': ('PGK', '598', 2, 'Kina'),
    'PHP': ('PHP', '608', 2, 'Peso filipino'),
    'PKR': ('PKR', '586', 2, 'Rupia pakistaní'),
    'PLN': ('PLN', '985', 2, 'Złoty'),
    'PYG': ('PYG', '600', 0, 'Guaraní'),
    'QAR': ('QAR', '634', 2, 'Riyal qatarí'),
    'RON': ('RON', '946', 2, 'Leu rumano'),
    'RSD': ('RSD', '941', 2, 'Dinar serbio'),
    'RUB': ('RUB', '643', 2, 'Rublo ruso'),
    'RWF': ('RWF', '646', 0, 'Franco ruandés'),
    'SAR': ('SAR', '682', 2, 'Riyal saudí'),
    'SBD': ('SBD', '90', 2, 'Dólar de las Islas Salomón'),
    'SCR': ('SCR', '690', 2, 'Rupia seychelense'),
    'SDG': ('SDG', '938', 2, 'Dinar sudanés'),
    'SEK': ('SEK', '752', 2, 'Corona sueca'),
    'SGD': ('SGD', '702', 2, 'Dólar de Singapur'),
    'SHP': ('SHP', '654', 2, 'Libra de Santa Elena'),
    'SLL': ('SLL', '694', 2, 'Leone'),
    'SOS': ('SOS', '706', 2, 'Chelín somalí'),
    'SRD': ('SRD', '968', 2, 'Dólar surinamés'),
    'SSP': ('SSP', '728', 2, 'Libra sursudanesa'),
    'STD': ('STD', '678', 2, 'Dobra'),
    'SVC': ('SVC', '222', 2, 'Colon Salvadoreño'),
    'SYP': ('SYP', '760', 2, 'Libra siria'),
    'SZL': ('SZL', '748', 2, 'Lilangeni'),
    'THB': ('THB', '764', 2, 'Baht'),
    'TJS': ('TJS', '972', 2, 'Somoni tayiko'),
    'TMT': ('TMT', '934', 2, 'Manat turcomano'),
    'TND': ('TND', '788', 3, 'Dinar tunecino'),
    'TOP': ('TOP', '776', 2, 'Paʻanga'),
    'TRY': ('TRY', '949', 2, 'Lira turca'),
    'TTD': ('TTD', '780', 2, 'Dólar de Trinidad y Tobago'),
    'TWD': ('TWD', '901', 2, 'Nuevo dólar taiwanés'),
    'TZS': ('TZS', '834', 2, 'Chelín tanzano'),
    'UAH': ('UAH', '980', 2, 'Grivna'),
    'UGX': ('UGX', '800', 0, 'Chelín ugandés'),
    'USD': ('USD', '840', 2, 'Dólar estadounidense'),
    'USN': ('USN', '997', 2, 'Dólar estadounidense (Siguiente día)'),
    'UYI': ('UYI', '940', 0, 'Peso en Unidades Indexadas (Uruguay)'),
    'UYU': ('UYU', '858', 2, 'Peso uruguayo'),
    'UZS': ('UZS', '860', 2, 'Som uzbeko'),
    'VEF': ('VEF', '937', 2, 'Bolívar'),
    'VND': ('VND', '704', 0, 'Dong vietnamita'),
    'VUV': ('VUV', '548', 0, 'Vatu'),
    'WST': ('WST', '882', 2, 'Tala'),
    'XAF': ('XAF', '950', 0, 'Franco CFA de África Central'),
    'XAG': ('XAG', '961', -1, 'Plata (una onza troy)'),
    'XAU': ('XAU', '959', -1, 'Oro (una onza troy)'),
    'XBA': ('XBA', '955', -1, 'Unidad compuesta europea (EURCO) (Unidad del mercados de bonos)'),  # noqa
    'XBB': ('XBB', '956', -1, 'Unidad Monetaria europea (E.M.U.-6) (Unidad del mercado de bonos)'),  # noqa
    'XBC': ('XBC', '957', -1, 'Unidad europea de cuenta 9 (E.U.A.-9) (Unidad del mercado de bonos)'),  # noqa
    'XBD': ('XBD', '958', -1, 'Unidad europea de cuenta 17 (E.U.A.-17) (Unidad del mercado de bonos)'),  # noqa
    'XCD': ('XCD', '951', 2, 'Dólar del Caribe Oriental'),
    'XDR': ('XDR', '960', -1, 'Derechos especiales de giro'),
    'XOF': ('XOF', '952', 0, 'Franco CFA de África Occidental'),
    'XPD': ('XPD', '964', -1, 'Paladio (una onza troy)'),
    'XPF': ('XPF', '953', 0, 'Franco CFP'),
    'XPT': ('XPT', '962', -1, 'Platino (una onza troy)'),
    'XSU': ('XSU', '994', -1, 'SUCRE'),
    'XTS': ('XTS', '963', -1, 'Reservado para pruebas'),
    'XUA': ('XUA', '965', -1, 'Unidad de cuenta BAD'),
    'XXX': ('XXX', '999', -1, 'Sin divisa'),
    'YER': ('YER', '886', 2, 'Rial yemení'),
    'ZAR': ('ZAR', '710', 2, 'Rand'),
    'ZMW': ('ZMW', '967', 2, 'Kwacha zambiano'),
    'ZWL': ('ZWL', '932', 2, 'Dólar zimbabuense')
}
